==> knative-model-4.6.0-sources.jar: annotations/io/fabric8/knative/eventing/v1alpha1/BrokerFluentImpl.java <==
package io.fabric8.knative.eventing.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class BrokerFluentImpl<A extends BrokerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements BrokerFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private BrokerSpecBuilder spec;
    private BrokerStatusBuilder status;

    public BrokerFluentImpl(){
    }
    public BrokerFluentImpl(Broker instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public BrokerFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public BrokerFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public BrokerFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public BrokerFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public BrokerFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public BrokerSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public BrokerSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(BrokerSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new BrokerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public BrokerFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public BrokerFluent.SpecNested<A> withNewSpecLike(BrokerSpec item){
            return new SpecNestedImpl(item);
    }

    public BrokerFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public BrokerFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new BrokerSpecBuilder().build());
    }

    public BrokerFluent.SpecNested<A> editOrNewSpecLike(BrokerSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public BrokerStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public BrokerStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(BrokerStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new BrokerStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public BrokerFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public BrokerFluent.StatusNested<A> withNewStatusLike(BrokerStatus item){
            return new StatusNestedImpl(item);
    }

    public BrokerFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public BrokerFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new BrokerStatusBuilder().build());
    }

    public BrokerFluent.StatusNested<A> editOrNewStatusLike(BrokerStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            BrokerFluentImpl that = (BrokerFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<BrokerFluent.MetadataNested<N>> implements BrokerFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) BrokerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends BrokerSpecFluentImpl<BrokerFluent.SpecNested<N>> implements BrokerFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final BrokerSpecBuilder builder;
    
            SpecNestedImpl(BrokerSpec item){
                    this.builder = new BrokerSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new BrokerSpecBuilder(this);
            }
    
    public N and(){
            return (N) BrokerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends BrokerStatusFluentImpl<BrokerFluent.StatusNested<N>> implements BrokerFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final BrokerStatusBuilder builder;
    
            StatusNestedImpl(BrokerStatus item){
                    this.builder = new BrokerStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new BrokerStatusBuilder(this);
            }
    
    public N and(){
            return (N) BrokerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}

==> knative-model-4.9.0-sources.jar: annotations/io/fabric8/knative/eventing/v1alpha1/BrokerFluentImpl.java <==
package io.fabric8.knative.eventing.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class BrokerFluentImpl<A extends BrokerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements BrokerFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private BrokerSpecBuilder spec;
    private BrokerStatusBuilder status;

    public BrokerFluentImpl(){
    }
    public BrokerFluentImpl(Broker instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public BrokerFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public BrokerFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public BrokerFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public BrokerFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public BrokerFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public BrokerSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public BrokerSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(BrokerSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new BrokerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public BrokerFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public BrokerFluent.SpecNested<A> withNewSpecLike(BrokerSpec item){
            return new SpecNestedImpl(item);
    }

    public BrokerFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public BrokerFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new BrokerSpecBuilder().build());
    }

    public BrokerFluent.SpecNested<A> editOrNewSpecLike(BrokerSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public BrokerStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public BrokerStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(BrokerStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new BrokerStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public BrokerFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public BrokerFluent.StatusNested<A> withNewStatusLike(BrokerStatus item){
            return new StatusNestedImpl(item);
    }

    public BrokerFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public BrokerFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new BrokerStatusBuilder().build());
    }

    public BrokerFluent.StatusNested<A> editOrNewStatusLike(BrokerStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            BrokerFluentImpl that = (BrokerFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<BrokerFluent.MetadataNested<N>> implements BrokerFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) BrokerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends BrokerSpecFluentImpl<BrokerFluent.SpecNested<N>> implements BrokerFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final BrokerSpecBuilder builder;
    
            SpecNestedImpl(BrokerSpec item){
                    this.builder = new BrokerSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new BrokerSpecBuilder(this);
            }
    
    public N and(){
            return (N) BrokerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends BrokerStatusFluentImpl<BrokerFluent.StatusNested<N>> implements BrokerFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final BrokerStatusBuilder builder;
    
            StatusNestedImpl(BrokerStatus item){
                    this.builder = new BrokerStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new BrokerStatusBuilder(this);
            }
    
    public N and(){
            return (N) BrokerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}
